@@ -84,6 +84,7 @@ class Graphics(Handler):
 
         def __init__(self):
             super().__init__()
+            self.multiline = False
         
         def setContainer(self, container):
             self.container = container
@@ -98,6 +99,7 @@ class Graphics(Handler):
 
         def __init__(self):
             super().__init__()
+            self.multiline = True
         
         def setContainer(self, container):
             self.container = container
@@ -346,7 +348,6 @@ class Graphics(Handler):
 
     def k_createLabel(self, command):
         text = self.compileConstant('')
-        size = self.compileConstant(20)
         while True:
             token = self.peek()
             if token == 'text':
@@ -354,7 +355,10 @@ class Graphics(Handler):
                 text = self.nextValue()
             elif token == 'size':
                 self.nextToken()
-                size = self.nextValue()
+                command['size'] = self.nextValue()
+            elif token == 'expand':
+                self.nextToken()
+                command['expand'] = True
             elif token == 'align':
                 self.nextToken()
                 token = self.nextToken()
@@ -362,7 +366,6 @@ class Graphics(Handler):
                     command['align'] = token
             else: break
         command['text'] = text
-        command['size'] = size
         self.add(command)
         return True
 
@@ -512,9 +515,13 @@ class Graphics(Handler):
         h = self.getRuntimeValue(command['h'])
         x = command['x']
         y = command['y']
-        if x == None: x = (self.program.screenWidth - w) / 2
+        if hasattr(self.program, 'screenWidth'): screenWidth = self.program.screenWidth
+        else: screenWidth = self.program.parent.program.screenWidth
+        if hasattr(self.program, 'screenHeight'): screenHeight = self.program.screenHeight
+        else: screenHeight = self.program.parent.program.screenHeight
+        if x == None: x = (screenWidth - w) / 2
         else: x = self.getRuntimeValue(x)
-        if y == None: y = (self.program.screenHeight - h) / 2
+        if y == None: y = (screenHeight - h) / 2
         else: y = self.getRuntimeValue(x)
         window.setGeometry(x, y, w, h)
         record['window'] = window
@@ -553,6 +560,8 @@ class Graphics(Handler):
             elif alignment == 'right': label.setAlignment(Qt.AlignRight)
             elif alignment in ['center', 'centre']: label.setAlignment(Qt.AlignHCenter)
             elif alignment == 'justify': label.setAlignment(Qt.AlignJustify)
+        if 'expand' in command:
+            label.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
         record['widget'] = label
         return self.nextPC()
     
@@ -643,8 +652,8 @@ class Graphics(Handler):
             dialog.textEdit.setText(dialog.value)
             mainLayout.addWidget(dialog.textEdit)
         buttonBox = QDialogButtonBox(QDialogButtonBox.Ok | QDialogButtonBox.Cancel)
-        buttonBox.accepted.connect(self.accept)
-        buttonBox.rejected.connect(self.reject)
+        buttonBox.accepted.connect(dialog.accept)
+        buttonBox.rejected.connect(dialog.reject)
         mainLayout.addWidget(buttonBox, alignment=Qt.AlignHCenter)
         record['dialog'] = dialog
         return self.nextPC()
@@ -989,7 +998,7 @@ class Graphics(Handler):
                 if record['keyword'] == 'checkbox':
                     command['name'] = record['name']
                     self.skip('to')
-                    command['value'] = self.nextToken()
+                    command['value'] = self.nextValue()
                     self.add(command)
                     return True
         elif token == 'alignment':
@@ -1082,7 +1091,7 @@ class Graphics(Handler):
         elif what == 'state':
             record = self.getVariable(command['name'])
             if record['keyword'] == 'checkbox':
-                state = True if command['value'] == 'checked' else False
+                state = self.getRuntimeValue(command['value'])
                 record['widget'].setChecked(state)
         elif what == 'alignment':
             widget = self.getVariable(command['name'])['widget']
